@@ -21,11 +21,19 @@ HASPT = function(angle, sptblocksize = 30, spt_max_gap = 60, ws3 = 5,
         angvar = stats::median(abs(diff(angle))) 
         return(angvar)
       }
-      # x = angle
-      # threshold = 0.2
       k1 = 5 * (60/ws3)
-      x = zoo::rollapply(angle, width = k1, FUN = medabsdi) # 5 minute rolling median of the absolute difference
-      threshold = HDCZA_threshold
+      
+      x = zoo::rollapply(angle, width = k1, FUN = medabsdi, fill = 0) # 5 minute rolling median of the absolute difference
+      if (is.null(HDCZA_threshold)) {
+        threshold = quantile(x, probs = 0.1) * 15
+        if (threshold < 0.13) {
+          threshold = 0.13
+        } else if (threshold > 0.50) {
+          threshold = 0.50
+        }
+      } else {
+        threshold = HDCZA_threshold
+      }
     } else if (HASPT.algo == "HorAngle") {  # if hip, then require horizontal angle
       # x = absolute angle
       # threshold = 45 degrees
@@ -83,8 +91,7 @@ HASPT = function(angle, sptblocksize = 30, spt_max_gap = 60, ws3 = 5,
       outofspt = c(0,outofspt,0)
       s3 = which(diff(outofspt) == 1) #start of blocks out of spt?
       e3 = which(diff(outofspt) == -1) #end blocks out of spt?
-      # starting block not to be filled, which will be a movement block at
-      # the start of the recording less than 60 minutes in length
+      # starting block not to be filled
       if (length(s3) > 0) {
         if (s3[1] == 1) {
           s3 = s3[-1]
@@ -93,8 +100,7 @@ HASPT = function(angle, sptblocksize = 30, spt_max_gap = 60, ws3 = 5,
       }
       if (length(e3) > 0) {
         if (e3[length(e3)] > length(x)) {
-          # ending block not to be filled, which will be a movement block at
-          # the end the recording less than 60 minutes in length
+          # ending block not to be filled
           s3 = s3[-length(s3)]
           e3 = e3[-length(e3)]
         }
