@@ -18,47 +18,50 @@ g.inspectfile = function(datafile, desiredtz = "", params_rawdata = c(),
   getbrand = function(filename = c(), datafile = c()) {
     sf = c(); isitageneactive = c(); mon = c(); dformat = c() #generating empty variables
     extension = unlist(strsplit(filename,"[.]"))
-    extension = extension[length(extension)]
+    if (tolower(extension[length(extension)]) == "gz") {
+      extension = extension[length(extension) - 1]
+    } else {
+      extension = extension[length(extension)]
+    }
     switch(extension,
-            "bin" = { dformat = FORMAT$BIN },
-            "cwa" = ,
-            "CWA" = { mon = MONITOR$AXIVITY
-            dformat = FORMAT$CWA
-            },
-            "gt3x" = { mon = MONITOR$ACTIGRAPH
-            dformat = FORMAT$GT3X
-            },
-            "GT3X" = { mon = MONITOR$ACTIGRAPH
-            dformat = FORMAT$GT3X
-            if (file.access(datafile, 2) == 0) { # test for write access to file
-              # rename file to be lower case gt3x extension
-              file.rename(from = datafile, to = gsub(pattern = ".GT3X", replacement = ".gt3x", x = datafile))
-              datafile = gsub(pattern = ".GT3X", replacement = ".gt3x", x = datafile)
-              warning("\nWe have renamed the GT3X file to gt3x because GGIR dependency read.gt3x cannot handle uper case extension")
-            } else {
-              stop("\nGGIR needs to change the file extension from GT3X to gt3x, but it does not seem to have write permission to the file.")
-            }
-            },
-            "csv" = { dformat = FORMAT$CSV
-            testheader = read.csv(datafile, nrow = 1, skip = 0, header = FALSE)
-            
-            if (grepl("ActiGraph", testheader[1], fixed=TRUE)) {
-              mon = MONITOR$ACTIGRAPH
-            } else {
-              testcsv = read.csv(datafile, nrow = 10, skip = 10)
-              testcsvtopline = read.csv(datafile, nrow = 2,skip = 1)
-              
-              if (ncol(testcsv) == 2 && ncol(testcsvtopline) < 4) {
-                mon = MONITOR$GENEACTIV
-              } else if (ncol(testcsv) >= 4 && ncol(testcsvtopline) >= 4) {
-                mon = MONITOR$AXIVITY
-              } else {
-                stop(paste0("\nError processing ", filename, ": unrecognised csv file format.\n"))
-              }
-            }
-            },
-            "wav" = { stop(paste0("\nError processing ", filename, ": Axivity .wav file format is no longer supported.\n")) },
-            { stop(paste0("\nError processing ", filename, ": unrecognised file format.\n")) }
+           "bin" = { dformat = FORMAT$BIN },
+           "cwa" = ,
+           "CWA" = { mon = MONITOR$AXIVITY
+           dformat = FORMAT$CWA
+           },
+           "gt3x" = { mon = MONITOR$ACTIGRAPH
+           dformat = FORMAT$GT3X
+           },
+           "GT3X" = { mon = MONITOR$ACTIGRAPH
+           dformat = FORMAT$GT3X
+           if (file.access(datafile, 2) == 0) { # test for write access to file
+             # rename file to be lower case gt3x extension
+             file.rename(from = datafile, to = gsub(pattern = ".GT3X", replacement = ".gt3x", x = datafile))
+             datafile = gsub(pattern = ".GT3X", replacement = ".gt3x", x = datafile)
+             warning("\nWe have renamed the GT3X file to gt3x because GGIR dependency read.gt3x cannot handle uper case extension")
+           } else {
+             stop("\nGGIR needs to change the file extension from GT3X to gt3x, but it does not seem to have write permission to the file.")
+           }
+           },
+           "csv" = { dformat = FORMAT$CSV
+           testheader = read.csv(datafile, nrow = 1, skip = 0, header = FALSE)
+
+           if (grepl("ActiGraph", testheader[1], fixed=TRUE)) {
+             mon = MONITOR$ACTIGRAPH
+           } else {
+             testcsv = read.csv(datafile, nrow = 10, skip = 10)
+             testcsvtopline = read.csv(datafile, nrow = 2,skip = 1)
+             if (ncol(testcsv) == 2 && ncol(testcsvtopline) < 4) {
+               mon = MONITOR$GENEACTIV
+             } else if (ncol(testcsv) >= 4 && ncol(testcsvtopline) >= 4) {
+               mon = MONITOR$AXIVITY
+             } else {
+               stop(paste0("\nError processing ", filename, ": unrecognised csv file format.\n"))
+             }
+           }
+           },
+           "wav" = { stop(paste0("\nError processing ", filename, ": Axivity .wav file format is no longer supported.\n")) },
+           { stop(paste0("\nError processing ", filename, ": unrecognised file format.\n")) }
     )
     
     if (ismovisens(datafile)) {
@@ -197,7 +200,7 @@ g.inspectfile = function(datafile, desiredtz = "", params_rawdata = c(),
                                     rmc.scalefactor.acc = params_rawdata[["rmc.scalefactor.acc"]],
                                     desiredtz = desiredtz,
                                     configtz = configtz)
-    if (inherits(Pusercsvformat$header, "character") && Pusercsvformat$header == "no header") {      
+    if (inherits(Pusercsvformat$header, "character") && Pusercsvformat$header == "no header") {
       sf = params_rawdata[["rmc.sf"]]
     } else {
       sf = as.numeric(Pusercsvformat$header["sample_rate",1])
@@ -208,14 +211,14 @@ g.inspectfile = function(datafile, desiredtz = "", params_rawdata = c(),
       stop("\nFile header doesn't specify sample rate. Please provide a non-zero rmc.sf value to process ", datafile)
     }
   }
-
+  
   if (mon == MONITOR$GENEACTIV && dformat == FORMAT$CSV) {
     stop(paste0("The GENEActiv csv reading functionality is deprecated in",
                 " GGIR from version 2.6-4 onwards. Please, use either",
                 " the GENEActiv bin files or try to read the csv files with",
                 " GGIR::read.myacc.csv"), call. = FALSE)
   }
-
+  
   if (dformat == FORMAT$BIN) {
     if (mon == MONITOR$GENEACTIV) {
       H = GGIRread::readGENEActiv(filename = datafile, start = 0, end = 1)$header
@@ -278,7 +281,7 @@ g.inspectfile = function(datafile, desiredtz = "", params_rawdata = c(),
   if (is.null(sf) || sf == 0) {
     warning(paste0("\nSample frequency not recognised in ", basename(datafile)), call. = FALSE)
   }
-
+  
   if (dformat != FORMAT$AD_HOC_CSV && is.null(sf) == FALSE) {
     H = as.matrix(H)
     if (ncol(H) == 3 && dformat == FORMAT$CSV && mon == MONITOR$ACTIGRAPH) {
@@ -329,7 +332,7 @@ g.inspectfile = function(datafile, desiredtz = "", params_rawdata = c(),
         mon = MONITOR$VERISENSE
       }
     }
-  } 
+  }
   if (!is.null(sf)) {
     # detect dot or comma separator in the data file
     op <- options(warn = -1) # turn off warnings
