@@ -37,7 +37,7 @@ knitr::opts_chunk$set(echo = TRUE)
 #        #=====================
 #        # Part 2
 #        #=====================
-#        strategy = 1,
+#        data_masking_strategy = 1,
 #        hrs.del.start = 0,          hrs.del.end = 0,
 #        maxdur = 9,                 includedaycrit = 16,
 #        qwindow=c(0,24),
@@ -86,9 +86,6 @@ knitr::include_graphics("reportexample.jpg")
 ## ----out.width = "700px",echo=FALSE-------------------------------------------
 knitr::include_graphics("example_dovisual.jpg")
 
-## ----out.width = "400px",echo=FALSE-------------------------------------------
-knitr::include_graphics("nonwearimage.jpg")
-
 ## ----echo=FALSE, out.width = "60%", out.extra='style="border: 0; padding:20px"'----
 knitr::include_graphics("GGIR-MASTERLOGO-RGB.png")
 
